@@ -109,11 +109,11 @@ TrialDesignSet <- setRefClass("TrialDesignSet",
 			return(.plotSettings)
 		},
 		
-		show = function(showType = 1) {
-			.show(showType = showType, consoleOutputEnabled = TRUE)
+		show = function(showType = 1, digits = NA_integer_) {
+			.show(showType = showType, digits = digits, consoleOutputEnabled = TRUE)
 		},
 		
-		.show = function(showType = 1, consoleOutputEnabled = TRUE) {
+		.show = function(showType = 1, digits = NA_integer_, consoleOutputEnabled = TRUE) {
 			'Method for automatically printing trial design sets'
 			.resetCat()
 			.cat("Trial design set with ", length(designs), " designs\n\n", heading = 1,
