@@ -426,240 +426,5 @@ getMedianByPi <- function(piValue, eventTime = C_EVENT_TIME_DEFAULT, kappa = 1)
 	getMedianByLambda(getLambdaByPi(piValue, eventTime, kappa), kappa)
 }
 
-.getFormattedSimpleBoundarySummaryValues <- function(values, digits = 3) {
-	return(sprintf(paste0("%.", digits, "f"), round(values, digits)))
-}
-
-.getSimpleBoundarySummaryParameter <- function(designPlan, parameterName, parameterCaption, ...,
-		roundDigits = NA_integer_, ceilingEnabeld = FALSE, cumsumEnabled = FALSE, 
-		parameterCaptionSingle = parameterCaption) {
-	
-	if (is.character(parameterName)) {
-		values <- designPlan[[parameterName]]
-	} else {
-		values <- parameterName
-	}
-	
-	parameterNames <- designPlan$.getVisibleFieldNamesOrdered()
-	numberOfVariants <- designPlan$.getMultidimensionalNumberOfVariants(parameterNames)
-	numberOfStages <- designPlan$.getMultidimensionalNumberOfStages(parameterNames)
-	
-	parameters <- c()
-	if ((!is.matrix(values) || ncol(values) == 1) && 
-			((numberOfStages > 1 && numberOfStages == length(values)) || length(values) != numberOfVariants)) {
-		if (cumsumEnabled) {
-			values <- cumsum(values)
-		}
-		if (ceilingEnabeld) {
-			values <- ceiling(values)
-		}
-		else if (!is.na(roundDigits)) {
-			#values <- round(values, roundDigits)
-			values <- .getFormattedSimpleBoundarySummaryValues(values, digits = roundDigits)
-		}
-		parameters <- list(values)
-		names(parameters) <- parameterCaptionSingle
-	} else {
-		variedParameter <- designPlan$.getVariedParameter(parameterNames, numberOfVariants)
-		variedParameterCaption <- designPlan$.getDataFrameColumnCaption(variedParameter, 
-			tableColumnNames = C_TABLE_COLUMN_NAMES, niceColumnNamesEnabled = TRUE)
-		variedParameterValues <- designPlan[[variedParameter]]
-		for (i in 1:numberOfVariants) {
-			if (length(values) <= 1) {
-				colValues <- values
-			} else if (is.matrix(values)) {
-				if (ncol(values) == 1) {
-					colValues <- values[i, 1]
-				} else {
-					colValues <- values[, i]
-				}
-			} else {
-				colValues <- values[i]
-			}
-			if (cumsumEnabled) {
-				colValues <- cumsum(colValues)
-			}
-			if (ceilingEnabeld) {
-				colValues <- ceiling(colValues)
-			}
-			else if (!is.na(roundDigits)) {
-				#colValues <- round(colValues, roundDigits)
-				colValues <- .getFormattedSimpleBoundarySummaryValues(colValues, digits = roundDigits)
-			}
-			parameter <- list(colValues)
-			names(parameter) <- paste0(parameterCaption, ", ", 
-				variedParameterCaption," = ", variedParameterValues[i])
-			parameters <- c(parameters, parameter)
-		}
-	}
-	return(parameters)
-}
-
-.getSimpleBoundarySummary <- function(designPlan) {
-	if (.isTrialDesignPlan(designPlan) || inherits(designPlan, "SimulationResults")) {
-		design <- designPlan$.design
-	}
-	else if (.isTrialDesign(designPlan)) {
-		design <- designPlan
-		designPlan <- NULL
-	}
-	else {
-		stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
-			"'designPlan' must be a valid design, design plan, ", 
-			"or simulation result object (is class ", class(designPlan), ")")
-	}
-	
-	designCharacteristics <- NULL
-	probsH0 <- NULL
-	probsH1 <- NULL
-	if (.isTrialDesignInverseNormalOrGroupSequential(design)) {
-		designCharacteristics <- getDesignCharacteristics(design)
-		probsH0 <- getPowerAndAverageSampleNumber(design, theta = 0, nMax = designCharacteristics$shift) 
-		probsH1 <- getPowerAndAverageSampleNumber(design, theta = 1, nMax = designCharacteristics$shift) 
-	}
-	if (!is.null(designPlan) && design$kMax > 1) {
-		probsH1 <- list(
-			earlyStop = designPlan$rejectPerStage[1:(design$kMax - 1), ] + designPlan$futilityPerStage,
-			rejectPerStage = designPlan$rejectPerStage,
-			futilityPerStage = designPlan$futilityPerStage
-		)
-	}
-	
-	parameters <- list(
-		"Stage" = c(1:design$kMax), 
-		"Information rate" = paste0(round(100 * design$informationRates, 1), "%")
-	)
-	
-	if (!is.null(designPlan)) {
-		if (design$kMax == 1) {
-			if (grepl("Survival", class(designPlan))) {
-				parameters <- c(parameters, 
-					.getSimpleBoundarySummaryParameter(designPlan, "eventsFixed", 
-						parameterCaption = "Cumulative number of events", roundDigits = 1))
-				parameters <- c(parameters, 
-					.getSimpleBoundarySummaryParameter(designPlan, "analysisTime", 
-						parameterCaption = "Analysis time under H1", roundDigits = 1))
-			} else {
-				parameters <- c(parameters, 
-					.getSimpleBoundarySummaryParameter(designPlan, "nFixed", 
-						parameterCaption = "Total sample size",
-						ceilingEnabeld = TRUE, cumsumEnabled = FALSE)) # TODO FALSE
-			}
-		} else {
-			if (grepl("Survival", class(designPlan))) {
-				parameters <- c(parameters, 
-					.getSimpleBoundarySummaryParameter(designPlan, "eventsPerStage", 
-						parameterCaption = "Cumulative number of events", roundDigits = 1))
-				parameters <- c(parameters, 
-					.getSimpleBoundarySummaryParameter(designPlan, "analysisTime", 
-						parameterCaption = "Analysis time under H1", roundDigits = 1))
-			} else {
-				parameters <- c(parameters, 
-					.getSimpleBoundarySummaryParameter(designPlan, "numberOfSubjects", 
-						parameterCaption = "Total sample size",
-						ceilingEnabeld = TRUE, cumsumEnabled = FALSE, # TODO FALSE
-						parameterCaptionSingle = "Total sample size (cumulative)"))
-			}
-		}
-	}
-	
-	parameters <- c(parameters, list(
-		"Cumulative alpha spent" = round(design$alphaSpent, 4)
-	))
-	if (!is.null(designPlan)) {
-		if (design$kMax > 1 || any(!is.na(designPlan$rejectPerStage))) {
-			parameters <- c(parameters, 
-				.getSimpleBoundarySummaryParameter(designPlan, "rejectPerStage", 
-					parameterCaption = "Cumulative power", roundDigits = 4, cumsumEnabled = TRUE))
-		}
-	} else if (!is.null(designCharacteristics)) {
-		parameters <- c(parameters, list(
-			"Cumulative power" = round(designCharacteristics$power, 3)
-		))
-	}
-	if (design$sided == 2) {
-		parameters <- c(parameters, list(
-			"Two-sided local significance level" = round(2 * design$stageLevels, 4)
-		))
-	} else {
-		parameters <- c(parameters, list(
-			"One-sided local significance level" = round(design$stageLevels, 4)
-		))
-	}
-	parameters <- c(parameters, list(
-		"Efficacy boundary (Z-value scale)" = round(design$criticalValues, 3)
-	))
-	
-	if (!is.null(designPlan) && .isTrialDesignPlan(designPlan)) {
-		if (ncol(designPlan$criticalValuesEffectScale) > 0) {
-			parameters <- c(parameters, 
-				.getSimpleBoundarySummaryParameter(designPlan, "criticalValuesEffectScale", 
-					parameterCaption = "Efficacy boundary (approximate treatment effect scale)", 
-					roundDigits = 3))
-		}
-		
-		if (ncol(designPlan$futilityBoundsEffectScale) > 0 && 
-			!all(is.na(designPlan$futilityBoundsEffectScale))) {
-			parameters <- c(parameters, 
-				.getSimpleBoundarySummaryParameter(designPlan, 
-					designPlan$futilityBoundsEffectScale, 
-					parameterCaption = "Futility boundary (approximate treatment effect scale)", 
-					roundDigits = 3))
-		}
-	}
-	
-	if (!is.null(probsH1) && !is.null(probsH0) && design$kMax > 1) {
-		
-		probsH0$earlyStop <- matrix(probsH0$earlyStop[1:(design$kMax - 1), 1], ncol = 1)
-		probsH0$rejectPerStage <- matrix(probsH0$rejectPerStage[1:(design$kMax - 1), 1], ncol = 1)
-		
-		if (is.matrix(probsH0$earlyStop)) {
-			probsH1$rejectPerStage <- probsH1$rejectPerStage[1:(design$kMax - 1), ]
-		} else {
-			probsH1$rejectPerStage <- probsH1$rejectPerStage[1:(design$kMax - 1)]
-		}
-	
-		if (any(design$futilityBounds > -6)) {
-			if (is.matrix(probsH0$earlyStop)) {
-				probsH1$earlyStop <- probsH1$earlyStop[1:(design$kMax - 1), ]
-			} else {
-				probsH1$earlyStop <- probsH1$earlyStop[1:(design$kMax - 1)]
-			}
-			parameters <- c(parameters, list(
-				"Overall exit probability (under H0)" = 
-					.getFormattedSimpleBoundarySummaryValues(probsH0$earlyStop, digits = 3)
-				))
-			parameters <- c(parameters, 
-				.getSimpleBoundarySummaryParameter(designPlan, probsH1$earlyStop, 
-					parameterCaption = "Overall exit probability (under H1)", 
-					roundDigits = 3))
-		}
-		parameters <- c(parameters, list(
-			"Exit probability for efficacy (under H0)" = 
-				.getFormattedSimpleBoundarySummaryValues(probsH0$rejectPerStage, digits = 3)
-			))
-		parameters <- c(parameters, 
-			.getSimpleBoundarySummaryParameter(designPlan, probsH1$rejectPerStage, 
-				parameterCaption = "Exit probability for efficacy (under H1)", 
-				roundDigits = 3))
-		if (any(design$futilityBounds > -6)) {
-			parameters <- c(parameters, list(
-				"Exit probability for futility (under H0)" = 
-					.getFormattedSimpleBoundarySummaryValues(probsH0$futilityPerStage, digits = 3)
-			))
-			parameters <- c(parameters, 
-				.getSimpleBoundarySummaryParameter(designPlan, probsH1$futilityPerStage, 
-					parameterCaption = "Exit probability for futility (under H1)", 
-					roundDigits = 3))
-		}
-	}
-	
-	names(parameters) <- paste0(format(names(parameters)), " ")
-	for (paramName in names(parameters)) {
-		values <- parameters[[paramName]]
-		values <- format(c("        ", values))[2:(length(values) + 1)]
-		cat(paramName, values, "\n")
-	}
-}
 
 
