@@ -5,7 +5,7 @@
 # This file is part of the R package RPACT - R Package for Adaptive Clinical Trials. #
 #                                                                                    #
 # File version: 1.0.0                                                                #
-# Date: 11 September 2019, 13:41:50                                                  #
+# Date: 06 November 2019, 17:12:23                                                   #
 # Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD                             #
 # Licensed under "GNU Lesser General Public License" version 3                       #
 # License text can be found here: https://www.r-project.org/Licenses/LGPL-3          #
@@ -41,21 +41,21 @@ test_that("'formatPValues'", {
 	##
 	## Comparison of the results of character object 'x' with expected results
 	##
-	expect_equal(x, c("0.0002346", "0.0000134", "0.1234000", "<0.0000001", "<0.0000001"))
+	expect_equal(x, c("0.0002346", "0.0000134", "0.1234000", "<0.000001", "<0.000001"))
 
 	x <- formatPValues(c(0.00234, 0.000013, 0.1234, 0.000000000001, .00000009999))
 
 	##
 	## Comparison of the results of character object 'x' with expected results
 	##
-	expect_equal(x, c("0.002340", "0.000013", "0.123400", "<0.00001", "<0.00001"))
+	expect_equal(x, c("0.00234", "<0.0001", "0.12340", "<0.0001", "<0.0001"))
 
 	x <- formatPValues(c(6.244e-05, 4.906e-02, 1.446e-02, NA_real_))
 
 	##
 	## Comparison of the results of character object 'x' with expected results
 	##
-	expect_equal(x, c("6.244e-05", "4.906e-02", "1.446e-02", "NA"))
+	expect_equal(x, c("<0.0001", "0.04906", "0.01446", "NA"))
 
 	x <- formatPValues(c(6.24408201934656e-05, 7.55449751868031e-05, 1.23207030919836e-05, NA_real_))
 
